#-------------------------------------------------------------------------------
# Identifier for configuration management tool TrueChange
# %Z% %M% %I% %G% %Z%
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Generic CSV Gateway

# Written by Stuart J. Tuck
# (c) Copyright IBM Corporation 2007. All rights reserved.

package EngineConfig;

@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

use strict;
use Exporter ();

use NETWORK_REGION_SEP qw(load_network_region_sep_config) ;
use NETWORK_REGION_CP  qw(load_network_region_cp_config)  ;

my $network_region_sep_config = &NETWORK_REGION_SEP::load_network_region_sep_config() ;
my $network_region_cp_config  = &NETWORK_REGION_CP::load_network_region_cp_config() ;


my %mth_arr=(
	'01' => 'Jan',
	'02' => 'Feb',
	'03' => 'Mar',
	'04' => 'Apr',
	'05' => 'May',
	'06' => 'Jun',
	'07' => 'Jul',
	'08' => 'Aug',
	'09' => 'Sep',
	'10'=> 'Oct',
	'11'=> 'Nov',
	'12'=> 'Dec',
);


#-------------------------------------------------------------------------------
# MS_DISK_MEAS rule 60 Minute data
#-------------------------------------------------------------------------------


my @rules = (


#-------------------------------------------------
# callParams.stats 
#-------------------------------------------------

#
	 
{ 	
	 RULE_TYPE 		  => 'GENERIC_CSV_GATEWAY',
	 RULE_DESC 		  => 'CSV Interface',
	 INPUT_FILE_DESCRIPTION   => [ '^callParams.stats.*$' ],
	 
	 FILENAME_HEADER_FIELDS   => {
					Filename=>'^(.*)',
					},
	 INPUT_DIR_DEPTH 	  => 3,

	 NUMBER_OF_FILES_TO_PROCESS => 20,
	 FIELD_SEPARATOR	  => '\t',
         DATA_FIELDS    => [0..9],
	 HEADER_OPTION  => ['Date_Time'      , 'messages_rxd'   , 'messages_sent', 
			    'Active_Dialogs' , 'Pending_Dialogs', 'Aborted_Dialogs',
		            'Send_Failures'  , 'TPS_1sec'       , 'Incoming_Queue_Time',
			    'TPS_3sec'],
	 
	 HEADER_DATA_RECORD_PROCESSING=> sub {
		my $prev_max_1min ;
		my $max_1min ;
		my $max_15min ;
		my $sep ="_" ;

		my( $blk_name_ref , $h_ref , $d_ref) = @_ ;
		my($mth , $day,$year, $time , $daymode) = split(' ',$d_ref->{'Date_Time'},5) ;
		my($hh,$mm,$ss) = split(':',$time,3) ;
		my $new_mm ;

		$d_ref->{'max_1min'} = "$day$mth$year$sep$hh:$mm$daymode" ;

		#----------------------------------------------------------
		#  To round down the minutes base on 15 minute interval
		#----------------------------------------------------------
		my $remainder=$mm%15;
	  	
		if($remainder > 0){
			$new_mm = ($mm * 1 ) - $remainder ;
			if($new_mm < 1 ) { $new_mm = "00" ; }
		}else {
			$new_mm = $mm ;
		}
		$d_ref->{'max_15min'} = "$day$mth$year$sep$hh:$new_mm$daymode" ;

		#-------------------------------------------------------
		# Manipulate Time and start date
		#-------------------------------------------------------
		$d_ref->{'START_TIME'} = "00:00" ;
		$d_ref->{'interval'} = '1440' ;
		$d_ref->{'START_DATE'} = "$day$mth$year" ;

		#---------------------------------------------------------
		# To add filename counter for uniq purpose
		#---------------------------------------------------------
		$d_ref->{'Filename'} = $h_ref->{Filename};


		#----------------------------------------------------------
		# To get SEP_ID
		#----------------------------------------------------------
		my $fname = $h_ref->{'Filename'} ;
		$fname =~ s/\./-/g ;
		my ($bname,$st,$sepid,$dtime) = split("-",$fname,4) ;
		$d_ref->{'SEP_ID'} = $sepid ;


		#----------------------------------------------------------
		# Network and Region ID mapping
		#----------------------------------------------------------
		if(exists $d_ref->{'SEP_ID'}){
			if(uc($d_ref->{'SEP_ID'}) eq $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"SEP"}){
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"NETWORK"} ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"REGION"} ;
			}
			else {
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = "UNDEFINED" ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = "UNDEFINED" ;

			}
		}


		#----------------------------------------------------------
		# To remove counter not in scope
		#----------------------------------------------------------	
		delete $d_ref->{'Active_Dialogs'} ;	
		delete $d_ref->{'Pending_Dialogs'} ;	
		delete $d_ref->{'Aborted_Dialogs'} ;	
		delete $d_ref->{'Send_Failures'} ;	
		delete $d_ref->{'Incoming_Queue_Time'} ;	

		return 0 ;
	 }
},

{
	 RULE_TYPE 		  => 'GENERIC_CSV_GATEWAY',
	 RULE_DESC 		  => 'CSV Interface',
	 INPUT_FILE_DESCRIPTION   => [ '^cpuLoad.stats.*$' ],
	 FILENAME_HEADER_FIELDS   => {
					Filename=>'^(.*)',
					},
	 INPUT_DIR_DEPTH          => 3,
	 FIELD_SEPARATOR	  => '\t',
         DATA_FIELDS    => [0..5],
	 HEADER_OPTION  => ['Date_Time','CPU0_1sec','CPU1_1sec','CPU2_1sec','CPU3_1sec'],
	 
	 HEADER_DATA_RECORD_PROCESSING=> sub {
		my $prev_max_1min ;
		my $max_1min ;
		my $max_15min ;
		my $sep ="_" ;

		my( $blk_name_ref , $h_ref , $d_ref) = @_ ;
		my($mth , $day,$year, $time , $daymode) = split(' ',$d_ref->{'Date_Time'},5) ;
		my($hh,$mm,$ss) = split(':',$time,3) ;
		my $new_mm ;

		$d_ref->{'max_1min'} = "$day$mth$year$sep$hh:$mm$daymode" ;


		#----------------------------------------------------------
		# To manipulate start time , period and start date
		#----------------------------------------------------------
		$d_ref->{'START_TIME'} = "00:00" ;
		$d_ref->{'interval'} = "1440" ;
		$d_ref->{'START_DATE'} = "$day$mth$year" ;

		#----------------------------------------------------------
		#  To round down the minutes base on 15 minute interval
		#----------------------------------------------------------
		my $remainder=$mm%15;
	  	
		if($remainder > 0){
			$new_mm = ($mm * 1 ) - $remainder ;
			if($new_mm < 1 ) { $new_mm = "00" ; }
		}else {
			$new_mm = $mm ;
		}
		$d_ref->{'max_15min'} = "$day$mth$year$sep$hh:$new_mm$daymode" ;

		#---------------------------------------------------------
		# To add filename counter for uniq purpose
		#---------------------------------------------------------
		$d_ref->{'Filename'} = $h_ref->{Filename};

		#----------------------------------------------------------
		# To get SEP_ID
		#----------------------------------------------------------
		my $fname = $h_ref->{'Filename'} ;
		$fname =~ s/\./-/g ;
		my ($bname,$st,$sepid,$dtime) = split("-",$fname,4) ;
		$d_ref->{'SEP_ID'} = $sepid ;

		#----------------------------------------------------------
		# Network and Region ID mapping
		#----------------------------------------------------------
		if(exists $d_ref->{'SEP_ID'}){
			if(uc($d_ref->{'SEP_ID'}) eq $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"SEP"}){
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"NETWORK"} ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = $network_region_sep_config->{uc($d_ref->{'SEP_ID'})}->{"REGION"} ;
			}
			else {
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = "UNDEFINED" ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = "UNDEFINED" ;

			}
		}

		return 0 ;
	 }
},

{
	 RULE_TYPE 		  => 'GENERIC_CSV_GATEWAY',
	 RULE_DESC 		  => 'CSV Interface',
	 INPUT_FILE_DESCRIPTION   => [ '^voice.traffic.stats.*$' ],
	 FILENAME_HEADER_FIELDS   => { Filename => '^(.*)', } ,
	 INPUT_DIR_DEPTH 	  => 3,
	 NUMBER_OF_FILES_TO_PROCESS => 20,
	 FIELD_SEPARATOR	  => ',',
         DATA_FIELDS    => [0..6],
         HEADER_OPTION  => ['cp','date','calltype','succ_count','fail_count','succ_vol','fail_vol'],
	 HEADER_DATA_RECORD_PROCESSING => sub {
		my( $blk_name_ref , $h_ref , $d_ref) = @_ ;
		$d_ref->{'CP_ID'} = $d_ref->{'cp'} ;
		$d_ref->{'CALL_TYPE_ID'} = $d_ref->{'calltype'} ;

		$d_ref->{'interval'} = "60";
		
		my $tdate = $d_ref->{'date'} ;
		
		my($vdate,$vtime) = split(" ",$tdate , 2) ;
		#my($hh,$sec) = split(":",$vtime,2) ;
		my($hh,$min,$sec) = split(":",$vtime,3) ;

		#---------------------------------
		# Manipulate date
		#---------------------------------
		$vdate =~ s/\./_/g ;
		my($yy,$mm,$dd) = split("_",$vdate,3) ;
		$mm = $mth_arr{$mm} ;
		$d_ref->{START_DATE} = "$dd$mm$yy" ;
		
		#---------------------------------
		# Manipulate time
		#---------------------------------
		$hh =~ s/\./:/g ;
		$d_ref->{'START_TIME'} = $hh ;
		$d_ref->{'START_TIME'} = "$hh:$min" ;

		#----------------------------------------------------------
		# Network and Region ID mapping
		#----------------------------------------------------------
		if(exists $d_ref->{'CP_ID'}){
			if(uc($d_ref->{'CP_ID'}) eq $network_region_cp_config->{uc($d_ref->{'CP_ID'})}->{"CP"}){
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = $network_region_cp_config->{uc($d_ref->{'CP_ID'})}->{"NETWORK"} ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = $network_region_cp_config->{uc($d_ref->{'CP_ID'})}->{"REGION"} ;
			}
			else {
				defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'} ;
				$h_ref->{'NETWORK_ID'} = "UNDEFINED" ;

				defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'} ;
				$h_ref->{'REGION_ID'} = "UNDEFINED" ;
			}
		}


		$$blk_name_ref = 'CP_VoiceStats_ALL_CT' ;
		return 0 ;
	 },
},

);  


sub engine_config {
    return \@rules;
}

1;
